@@ -8,19 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_codecommit._jsii
-import aws_cdk.aws_codepipeline._jsii
-import aws_cdk.aws_codepipeline_actions._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+from typeguard import check_type
+
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-codepipeline-merge-action",
-    "1.51.0",
+    "2.3.0",
     __name__[0:-6],
-    "cdk-codepipeline-merge-action@1.51.0.jsii.tgz",
+    "cdk-codepipeline-merge-action@2.3.0.jsii.tgz",
 )
 
 __all__ = [
